package com.arms.api.alm.utils;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.mockito.MockedStatic;
import org.mockito.Mockito;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.core.env.Environment;
import org.springframework.test.context.ActiveProfiles;

import java.time.Clock;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Arrays;

import static com.arms.api.util.env.ApplicationProfile.DEV;
import static com.arms.config.ApplicationContextProvider.getBean;
import static org.junit.jupiter.api.Assertions.*;

import com.arms.api.util.env.ApplicationProfile;
import com.arms.api.util.alm.지라유틸;

@ActiveProfiles("dev")
@SpringBootTest
class 지라유틸Test_dev {

    @Autowired
    private Environment environment;

    @Test
    @DisplayName("전일_업데이트여부_개발용 테스트")
    public void 전일_업데이트여부(){

        ZonedDateTime fixedDateTime = ZonedDateTime.of(
                2024, 10, 7, 3, 0, 0, 0, ZoneId.systemDefault());

        final Clock fixedClock = Clock.fixed(fixedDateTime.toInstant(), ZoneId.systemDefault());

        try (MockedStatic<Clock> mockClock = Mockito.mockStatic(Clock.class)) {
            mockClock.when(Clock::systemDefaultZone).thenReturn(fixedClock);

            assertTrue(지라유틸.전일_업데이트여부("2024-10-07T02:59:59.000+0900"));//24시간내
            assertFalse(지라유틸.전일_업데이트여부("2024-10-04T02:59:59.000+0900"));//24시간 이전
            assertFalse(지라유틸.전일_업데이트여부("2024-10-08T02:59:59.000+0900"));//미래

        }

    }

    @Test
    @DisplayName("환경프로파일 데브환경인지 테스트")
    public void 환경프로파일_테스트(){
        Environment environment = getBean(Environment.class);

        Boolean existsProfile = Arrays.stream(environment.getActiveProfiles())
                .findFirst()
                .map(a -> ApplicationProfile.valueOf(a.toUpperCase()).equals(DEV))
                .orElse(false);

        assertTrue(existsProfile);

    }

    @Test
    @DisplayName("환경프로파일 dev yml jira jql 프로퍼티 확인하기")
    public void jql_프로퍼티_dev_테스트(){
        String jql = environment.getProperty("jira.api.parameter.jql.updated");
        assertEquals(jql,"(updated >= -48h AND updated <= now())");
    }

}
